@@ -18,49 +18,53 @@ rmd_template <- function(...,
                            "-auto_identifiers"    # disables \hypertarget commands
                          )) {
   template <- system.file("rmarkdown", "templates", template_name, "resources", "template.tex", package = "rosr")
-  fmt <- rmarkdown::pdf_document(..., template = template, keep_tex = keep_tex)
-  fmt$inherits <- "pdf_document"
-  fmt
+  if (!rmarkdown::pandoc_available()) {
+    return("Pandoc is required.")
+  } else {
+    fmt <- rmarkdown::pdf_document(..., template = template, keep_tex = keep_tex)
+    fmt$inherits <- "pdf_document"
+    return(fmt)
+  }
 }
 
 #' @rdname rmd_template
 #' @export
 statement_svm <- function(...){
-  rmd_template(template_name = "statement_svm")
+  rmd_template(template_name = "statement_svm", ...)
 }
 
 #' @rdname rmd_template
 #' @export
 article_svm <- function(...){
-  rmd_template(template_name = "article_svm")
+  rmd_template(template_name = "article_svm", ...)
 }
 
 #' @rdname rmd_template
 #' @export
 cv_svm <- function(...){
-  rmd_template(template_name = "cv_svm")
+  rmd_template(template_name = "cv_svm", ...)
 }
 
 #' @rdname rmd_template
 #' @export
 syllabus_svm <- function(...){
-  rmd_template(template_name = "syllabus_svm")
+  rmd_template(template_name = "syllabus_svm", ...)
 }
 
 #' @rdname rmd_template
 #' @export
 manuscript_svm <- function(...){
-  rmd_template(template_name = "manuscript_svm")
+  rmd_template(template_name = "manuscript_svm", ...)
 }
 
 #' @rdname rmd_template
 #' @export
 letter_moderncv <- function(...){
-  rmd_template(template_name = "letter_moderncv")
+  rmd_template(template_name = "letter_moderncv", ...)
 }
 
 #' @rdname rmd_template
 #' @export
-beamer_zh <- function(...){
-  rmd_template(template_name = "beamer_zh")
+beamer <- function(...){
+  rmd_template(template_name = "beamer", ...)
 }
